<?php
global $_DBCONFIG, $loggableListener, $apcEnabled, $pdo, $_CONFIG;

use Doctrine\Common\Util\Debug as DoctrineDebug;
use Cx\Model\Events\PageEventListener as PageEventListener;

require_once(ASCMS_CORE_PATH.'/Env.class.php');
require_once(ASCMS_MODEL_PATH.'/events/PageEventListener.class.php');

$doctrineDir = ASCMS_LIBRARY_PATH.'/doctrine/';

//require_once $doctrineDir.'vendor/doctrine-common/lib/Doctrine/Common/ClassLoader.php';
//use \Doctrine\Common\ClassLoader as ClassLoader;
require_once ASCMS_CORE_PATH.'/ClassLoader.class.php';
use \Cx\ClassLoader as ClassLoader;

$classLoader = new ClassLoader('Doctrine\ORM', realpath($doctrineDir));
$classLoader->register();
$classLoader = new ClassLoader('Doctrine\DBAL', realpath($doctrineDir.'/vendor/doctrine-dbal/lib'));
$classLoader->register();
$classLoader = new ClassLoader('Doctrine\Common', realpath($doctrineDir.'/vendor/doctrine-common/lib'));
$classLoader->register();
$classLoader = new ClassLoader('Symfony', realpath($doctrineDir.'/vendor'));
$classLoader->register();
$classLoader = new ClassLoader('Cx\Model', ASCMS_MODEL_PATH.'/entities');
$classLoader->register();
$classLoader = new ClassLoader('Cx\Model\Proxies', ASCMS_MODEL_PROXIES_PATH);
$classLoader->register();

$classLoader = new ClassLoader('DoctrineExtension', ASCMS_MODEL_PATH.'/extensions');
$classLoader->register();

$classLoader = new ClassLoader('Gedmo\Loggable\Entity', ASCMS_MODEL_PATH.'/entities');
$classLoader->register();

$classLoader = new ClassLoader('Gedmo', $doctrineDir);
$classLoader->register();

$config = new \Doctrine\ORM\Configuration();

if ($apcEnabled) {
    $cache = new \Doctrine\Common\Cache\ApcCache();
} else {
    $cache = new \Doctrine\Common\Cache\ArrayCache();
}
$config->setResultCacheImpl($cache);
$config->setMetadataCacheImpl($cache);
$config->setQueryCacheImpl($cache);

$config->setProxyDir(ASCMS_MODEL_PROXIES_PATH);
$config->setProxyNamespace('Cx\Model\Proxies');
$config->setAutoGenerateProxyClasses(false);

if (!isset($pdo)) {
    $objDateTimeZone = new DateTimeZone($_CONFIG['timezone']);
    $objDateTime = new DateTime('now', $objDateTimeZone);
    $offset = $objDateTimeZone->getOffset($objDateTime);
    $offsetHours = round(abs($offset)/3600); 
    $offsetMinutes = round((abs($offset)-$offsetHours*3600) / 60); 
    $offsetString = ($offset > 0 ? '+' : '-').($offsetHours < 10 ? '0' : '').$offsetHours.':'.($offsetMinutes < 10 ? '0' : '').$offsetMinutes;
    
    $pdo = new \PDO(
        'mysql:dbname=' . $_DBCONFIG['database'] . ';charset=' . $_DBCONFIG['charset'] . ';host='.$_DBCONFIG['host'],
        $_DBCONFIG['user'],
        $_DBCONFIG['password'],
        array(
            // Setting the connection character set in the DSN (see below new \PDO()) prior to PHP 5.3.6 did not work.
            // We will have to manually do it by executing the SET NAMES query when connection to the database.
            \PDO::MYSQL_ATTR_INIT_COMMAND => 'SET NAMES '.$_DBCONFIG['charset'],
            \PDO::MYSQL_ATTR_INIT_COMMAND => 'SET time_zone = \'' . $offsetString . '\'',
        )
    );
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_SILENT);
}

$connectionOptions = array(
    'pdo' => $pdo,
);

$evm = new \Doctrine\Common\EventManager();

$chainDriverImpl = new \Doctrine\ORM\Mapping\Driver\DriverChain();
$driverImpl = new \Doctrine\ORM\Mapping\Driver\YamlDriver(ASCMS_MODEL_PATH.'/yml');
$chainDriverImpl->addDriver($driverImpl, 'Cx\Model');

//loggable stuff
$loggableDriverImpl = $config->newDefaultAnnotationDriver(array(
    $doctrineDir.'Gedmo/Loggable/Entity', // Document for ODM
));
$chainDriverImpl->addDriver($loggableDriverImpl, 'Gedmo\Loggable');

$loggableListener = new \Gedmo\Loggable\LoggableListener();
$loggableListener->setUsername('currently_loggedin_user');
// in real world app the username should be loaded from session, example:
// Session::getInstance()->read('user')->getUsername();
$evm->addEventSubscriber($loggableListener);

//tree stuff
$treeListener = new \Gedmo\Tree\TreeListener();
$evm->addEventSubscriber($treeListener);
$config->setMetadataDriverImpl($chainDriverImpl);

//table prefix
$prefixListener = new \DoctrineExtension\TablePrefixListener($_DBCONFIG['tablePrefix']);
$evm->addEventListener(\Doctrine\ORM\Events::loadClassMetadata, $prefixListener);

//page listener for unique slugs
$pageListener = new PageEventListener();
$evm->addEventListener(\Doctrine\ORM\Events::prePersist,  $pageListener);
$evm->addEventListener(\Doctrine\ORM\Events::postPersist, $pageListener);
$evm->addEventListener(\Doctrine\ORM\Events::preUpdate,   $pageListener);
$evm->addEventListener(\Doctrine\ORM\Events::postUpdate,  $pageListener);
$evm->addEventListener(\Doctrine\ORM\Events::preRemove,   $pageListener);
$evm->addEventListener(\Doctrine\ORM\Events::postRemove,  $pageListener);
$evm->addEventListener(\Doctrine\ORM\Events::onFlush,     $pageListener);

$config->setSqlLogger(new \Cx\Lib\DBG\DoctrineSQLLogger());

$em = \Doctrine\ORM\EntityManager::create($connectionOptions, $config, $evm);

//resolve enum, set errors
$conn = $em->getConnection();
$conn->setCharset($_DBCONFIG['charset']); 
$conn->getDatabasePlatform()->registerDoctrineTypeMapping('enum', 'string');
$conn->getDatabasePlatform()->registerDoctrineTypeMapping('set', 'string');

Env::setEm($em);


